handler

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2017 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handler

Handler() should be invoked to handle responding to the passed-in HTTP request. Responses are sent via the passed-in http.ResponseWriter.

The passed-in RESTController is first initialized using the specified http.ResponseWriter and http.Request, and is connected to the Skills database. Once initialized, the RESTController is used to handle responses to the passed-in HTTP request.

If the RESTController generates any errors, then Handler() will log them, and respond to the request with the appropriate error.

func MakeHandler

MakeHandler() returns a new function of the adapter type http.HandlerFunc using the passed-in function, fn.

Types

This section is empty.

Jump to