Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Handler ¶
func Handler(w http.ResponseWriter, r *http.Request, cont controller.RESTController, session data.DataAccess, fs data.FileSystem)
Handler() should be invoked to handle responding to the passed-in HTTP request. Responses are sent via the passed-in http.ResponseWriter.
The passed-in RESTController is first initialized using the specified http.ResponseWriter and http.Request, and is connected to the Skills database. Once initialized, the RESTController is used to handle responses to the passed-in HTTP request.
If the RESTController generates any errors, then Handler() will log them, and respond to the request with the appropriate error.
func MakeHandler ¶
func MakeHandler( fn func(http.ResponseWriter, *http.Request, controller.RESTController, data.DataAccess, data.FileSystem), cont controller.RESTController, session data.DataAccess, fs data.FileSystem) http.HandlerFunc
MakeHandler() returns a new function of the adapter type http.HandlerFunc using the passed-in function, fn.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.